package com.rockymadden.jbrainhoney;

/**
 * Defines the interface of a complex ValueClass. Classes implementing methods in this interface must meet the
 * documented requirements.
 */
public abstract interface ComplexValueClass extends ValueClass {
	/**
	 * Returns complex string representation of this class. The string representation consists of the simple class
	 * name followed by an opening parenthesis followed by a list of attribute-value mappings in alphabetical order
	 * (by attribute) followed by a closing parenthesis. Adjacent mappings are separated by the comma and space
	 * characters. Each attribute-value mapping is rendered as the attribute followed by an equals sign followed by the
	 * associated value. Primitive values are converted to strings. Non-primitive values are converted to strings via
	 * their toString method. Arrays are converted to strings via the Arrays.toString method. Enums are converted to
	 * strings via their toString method.
	 *
	 * @return A complex string representation of this class.
	 */
	@Override
	public abstract String toString();

	/** Defines the interface of a ComplexValueClass builder. */
	public static interface Builder extends ValueClass.Builder {
		@Override
		public abstract ComplexValueClass build();
	}
}
