package com.rockymadden.jbrainhoney.cryptography;

import java.util.EnumSet;
import com.rockymadden.jbrainhoney.SimpleValueClass;

/** Defines the interface of a digest. */
public abstract interface Digest extends SimpleValueClass {
	public abstract Algorithm getAlgorithm();

	public abstract byte[] getMessage();

	public abstract byte[] compute();

	public abstract String computeAsString();

	/** Defines the interface of a Digest builder. */
	public static interface Builder {
		public abstract Digest build();
	}

	/** Enumerates digest algorithms. */
	public enum Algorithm {
		MD2("MD2", 128),
		MD5("MD5", 128),
		SHA1("SHA-1", 160),
		SHA256("SHA-256", 256),
		SHA384("SHA-384", 384),
		SHA512("SHA-512", 512);

		private final String name;
		private final int bits;

		private Algorithm(final String name, final int bits) {
			this.name = name;
			this.bits = bits;
		}

		public String getName() {
			return name;
		}

		public int getBits() {
			return bits;
		}

		public static Algorithm valueOfName(final String name) throws IllegalArgumentException {
			if(name == null) throw new IllegalArgumentException("Expected name to not be null.");

			Algorithm enumeration = null;

			for(Algorithm element : EnumSet.allOf(Algorithm.class)) {
				if(element.getName() != null && element.getName().equals(name)) {
					enumeration = element;
					break;
				}
			}

			if(enumeration == null) throw new IllegalArgumentException("Expected name match.");

			return enumeration;
		}
	}
}
