package com.rockymadden.jbrainhoney.dlap.command;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import com.rockymadden.jbrainhoney.dlap.element.User;

/**
 * A command which creates one or more users. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/CreateUsers">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class CreateUsersCommand implements Command {
	private final List<User> users;

	@SuppressWarnings("synthetic-access")
	private CreateUsersCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.users == null || builder.users.size() == 0)
			throw new IllegalArgumentException("Expected users to not be null.");

		for(User user : builder.users) {
			if(user == null) throw new IllegalArgumentException("Expected user to not be null.");
			else if(user.getUsername() == null || user.getPassword() == null || user.getFirstName() == null
				|| user.getLastName() == null || user.getEmail() == null || user.getDomainId() == null) {

				throw new IllegalArgumentException("Expected username, password, firstName, lastName, email, and domainId to all not be null.");
			}
		}

		users = Collections.unmodifiableList(new ArrayList<User>(builder.users));
	}

	public List<User> getUsers() {
		return users;
	}

	/** A builder of immutable CreateUsersCommand instances. */
	public final static class Builder implements Command.Builder {
		private final List<User> users;

		public Builder(final List<User> users) {
			super();

			if(users == null) this.users = Collections.synchronizedList(new ArrayList<User>());
			else this.users = Collections.synchronizedList(new ArrayList<User>(users));
		}

		public Builder(final User user) {
			super();

			if(user == null) users = Collections.synchronizedList(new ArrayList<User>());
			else users = Collections.synchronizedList(new ArrayList<User>(Arrays.asList(user)));
		}

		public Builder addUser(final User user) {
			users.add(user);

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public CreateUsersCommand build() {
			return new CreateUsersCommand(this);
		}
	}
}