package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets information for a course. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetCourse">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class GetCourseCommand implements Command {
	private final String courseId;

	@SuppressWarnings("synthetic-access")
	private GetCourseCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.courseId == null) throw new IllegalArgumentException("Expected courseId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.courseId))
			throw new IllegalArgumentException("Expected courseId to be valid.");

		courseId = builder.courseId;
	}

	public String getCourseId() {
		return courseId;
	}

	/** A builder of immutable GetCourseCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String courseId;

		public Builder(final String courseId) {
			super();

			this.courseId = courseId;
		}

		public Builder(final Integer courseId) {
			super();

			this.courseId = (courseId == null ? null : courseId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetCourseCommand build() {
			return new GetCourseCommand(this);
		}
	}
}