package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets information for the specified domain. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetDomain">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class GetDomainCommand implements Command {
	private final String domainId;

	@SuppressWarnings("synthetic-access")
	private GetDomainCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.domainId == null) throw new IllegalArgumentException("Expected domainId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.domainId))
			throw new IllegalArgumentException("Expected domainId to be valid.");

		domainId = builder.domainId;
	}

	public String getDomainId() {
		return domainId;
	}

	/** A builder of immutable GetDomainsCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String domainId;

		public Builder(final String domainId) {
			super();

			this.domainId = domainId;
		}

		public Builder(final Integer domainId) {
			super();

			this.domainId = (domainId == null ? null : domainId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetDomainCommand build() {
			return new GetDomainCommand(this);
		}
	}
}