package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets information for a enrollment. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetEnrollment2">the BrainHoney DLAP API guide</a>} for this
 * command.
 */
public final class GetEnrollmentCommand implements Command {
	private final String enrollmentId;

	@SuppressWarnings("synthetic-access")
	private GetEnrollmentCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.enrollmentId == null) throw new IllegalArgumentException("Expected enrollmentId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.enrollmentId))
			throw new IllegalArgumentException("Expected enrollmentId to be greater than 0.");

		enrollmentId = builder.enrollmentId;
	}

	public String getEnrollmentId() {
		return enrollmentId;
	}

	/** A builder of immutable GetEnrollmentCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String enrollmentId;

		public Builder(final String enrollmentId) {
			super();

			this.enrollmentId = enrollmentId;
		}

		public Builder(final Integer enrollmentId) {
			super();

			this.enrollmentId = (enrollmentId == null ? null : enrollmentId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetEnrollmentCommand build() {
			return new GetEnrollmentCommand(this);
		}
	}
}