package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.enumeration.RightFlag;
import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets the list of users enrolled in the specified entity. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetEntityEnrollmentList2">the BrainHoney DLAP API guide</a>} for
 * this command.
 */
public final class GetEntityEnrollmentListCommand implements Command {
	private final Boolean all;
	private final String entityId;
	private final Long flags;
	private final String userId;

	@SuppressWarnings("synthetic-access")
	private GetEntityEnrollmentListCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.entityId == null) throw new IllegalArgumentException("Expected entityId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.entityId))
			throw new IllegalArgumentException("Expected entityId to be valid.");
		else if(builder.userId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.userId))
			throw new IllegalArgumentException("Expected userId to be valid.");

		all = builder.all;
		entityId = builder.entityId;
		flags = builder.flags;
		userId = builder.userId;
	}

	public Boolean getAll() {
		return all;
	}

	public String getEntityId() {
		return entityId;
	}

	public Long getFlags() {
		return flags;
	}

	public String getUserId() {
		return userId;
	}

	/** A builder of immutable GetEntityEnrollmentListCommand instances. */
	public final static class Builder implements Command.Builder {
		private Boolean all;
		private final String entityId;
		private Long flags;
		private String userId;

		public Builder(final String entityId) {
			super();

			this.entityId = entityId;
		}

		public Builder(final Integer entityId) {
			super();

			this.entityId = (entityId == null ? null : entityId.toString());
		}

		public Builder setAll(final Boolean all) {
			this.all = all;

			return this;
		}

		public Builder setFlags(final Long flags) {
			this.flags = flags;

			return this;
		}

		public Builder setFlags(final RightFlag flags) {
			this.flags = flags.getValue();

			return this;
		}

		public Builder setUserId(final String userId) {
			this.userId = userId;

			return this;
		}

		public Builder setUserId(final Integer userId) {
			this.userId = (userId == null ? null : userId.toString());

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetEntityEnrollmentListCommand build() {
			return new GetEntityEnrollmentListCommand(this);
		}
	}
}