package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets information for a particular group. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetGroup">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class GetGroupCommand implements Command {
	private final String groupId;

	@SuppressWarnings("synthetic-access")
	private GetGroupCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.groupId == null) throw new IllegalArgumentException("Expected groupId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.groupId))
			throw new IllegalArgumentException("Expected groupId to be valid.");

		groupId = builder.groupId;
	}

	public String getGroupId() {
		return groupId;
	}

	/** A builder of immutable GetGroupCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String groupId;

		public Builder(final String groupId) {
			super();

			this.groupId = groupId;
		}

		public Builder(final Integer groupId) {
			super();

			this.groupId = (groupId == null ? null : groupId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetGroupCommand build() {
			return new GetGroupCommand(this);
		}
	}
}