package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets the rights granted to the specified actor (user or role) for the specified entity
 * (domain, course, or section). See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetRights">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class GetRightCommand implements Command {
	private final String actorId;
	private final String entityId;

	@SuppressWarnings("synthetic-access")
	private GetRightCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.actorId == null) throw new IllegalArgumentException("Expected actorId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.actorId))
			throw new IllegalArgumentException("Expected actorId to be valid.");
		else if(builder.entityId == null) throw new IllegalArgumentException("Expected entityId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.entityId))
			throw new IllegalArgumentException("Expected entityId to be valid.");

		actorId = builder.actorId;
		entityId = builder.entityId;
	}

	public String getActorId() {
		return actorId;
	}

	public String getEntityId() {
		return entityId;
	}

	/** A builder of immutable GetRightCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String actorId;
		private final String entityId;

		public Builder(final String actorId, final String entityId) {
			super();

			this.actorId = actorId;
			this.entityId = entityId;
		}

		public Builder(final Integer actorId, final String entityId) {
			super();

			this.actorId = (actorId == null ? null : actorId.toString());
			this.entityId = entityId;
		}

		public Builder(final String actorId, final Integer entityId) {
			super();

			this.actorId = actorId;
			this.entityId = (entityId == null ? null : entityId.toString());
		}

		public Builder(final Integer actorId, final Integer entityId) {
			super();

			this.actorId = (actorId == null ? null : actorId.toString());
			this.entityId = (entityId == null ? null : entityId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetRightCommand build() {
			return new GetRightCommand(this);
		}
	}
}