package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.enumeration.RightFlag;
import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which lists sections. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetSectionList">the BrainHoney DLAP API guide</a>} for this
 * command.
 */
public final class GetSectionListCommand implements Command {
	private final String courseId;
	private final String domainId;
	private final Long flags;
	private final String title;

	@SuppressWarnings("synthetic-access")
	private GetSectionListCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.courseId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.courseId))
			throw new IllegalArgumentException("Expected courseId to be valid.");
		else if(builder.domainId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.domainId))
			throw new IllegalArgumentException("Expected domainId to be valid.");

		courseId = builder.courseId;
		domainId = builder.domainId;
		flags = builder.flags;
		title = builder.title;
	}

	public String getCourseId() {
		return courseId;
	}

	public String getDomainId() {
		return domainId;
	}

	public Long getFlags() {
		return flags;
	}

	public String getTitle() {
		return title;
	}

	/** A builder of immutable GetSectionListCommand instances. */
	public final static class Builder implements Command.Builder {
		private String courseId;
		private String domainId;
		private Long flags;
		private String title;

		public Builder() {
			super();
		}

		public Builder setCourseId(final String courseId) {
			this.courseId = courseId;

			return this;
		}

		public Builder setCourseId(final Integer courseId) {
			this.courseId = (courseId == null ? null : courseId.toString());

			return this;
		}

		public Builder setDomainId(final String domainId) {
			this.domainId = domainId;

			return this;
		}

		public Builder setDomainId(final Integer domainId) {
			this.domainId = (domainId == null ? null : domainId.toString());

			return this;
		}

		public Builder setFlags(final Long flags) {
			this.flags = flags;

			return this;
		}

		public Builder setFlags(final RightFlag flags) {
			this.flags = flags.getValue();

			return this;
		}

		public Builder setTitle(final String title) {
			this.title = title;

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetSectionListCommand build() {
			return new GetSectionListCommand(this);
		}
	}
}