package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which gets information for a particular user. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/GetUser">the BrainHoney DLAP API guide</a>} for this command.
 */
public final class GetUserCommand implements Command {
	private final String userId;

	@SuppressWarnings("synthetic-access")
	private GetUserCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.userId == null) throw new IllegalArgumentException("Expected userId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.userId))
			throw new IllegalArgumentException("Expected userId to be valid.");

		userId = builder.userId;
	}

	public String getUserId() {
		return userId;
	}

	/** A builder of immutable GetUserCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String userId;

		public Builder(final String userId) {
			super();

			this.userId = userId;
		}

		public Builder(final Integer userId) {
			super();

			this.userId = (userId == null ? null : userId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public GetUserCommand build() {
			return new GetUserCommand(this);
		}
	}
}