package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which lists domains that have been deleted and can be restored. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/ListRestorableDomains"> the BrainHoney DLAP API guide</a>} for
 * this command.
 */
public final class ListRestorableDomainsCommand implements Command {
	private final String parentId;

	@SuppressWarnings("synthetic-access")
	private ListRestorableDomainsCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.parentId == null) throw new IllegalArgumentException("Expected parentId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.parentId))
			throw new IllegalArgumentException("Expected parentId to be valid.");

		parentId = builder.parentId;
	}

	public String getParentId() {
		return parentId;
	}

	/** A builder of immutable ListRestorableDomainsCommand instances. */
	public final static class Builder implements Command.Builder {
		private final String parentId;

		public Builder(final String parentId) {
			super();

			this.parentId = parentId;
		}

		public Builder(final Integer parentId) {
			super();

			this.parentId = (parentId == null ? null : parentId.toString());
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public ListRestorableDomainsCommand build() {
			return new ListRestorableDomainsCommand(this);
		}
	}
}