package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which lists enrollments that have been deleted and can be restored. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/ListRestorableEnrollments">the BrainHoney DLAP API guide</a>} for
 * this command. */
public final class ListRestorableEnrollmentsCommand implements Command {
	private final String entityId;
	private final String userId;

	@SuppressWarnings("synthetic-access")
	private ListRestorableEnrollmentsCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.entityId == null && builder.userId == null)
			throw new IllegalArgumentException("Expected domainId or userId to not be null.");
		else if(builder.entityId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.entityId))
			throw new IllegalArgumentException("Expected entityId to be valid.");
		else if(builder.userId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.userId))
			throw new IllegalArgumentException("Expected userId to be valid.");

		entityId = builder.entityId;
		userId = builder.userId;
	}

	public String getEntityId() {
		return entityId;
	}

	public String getUserId() {
		return userId;
	}

	/** A builder of immutable ListRestorableEnrollmentsCommand instances. */
	public final static class Builder implements Command.Builder {
		private String entityId;
		private String userId;

		public Builder() {
			super();
		}

		public Builder setEntityId(final String entityId) {
			this.entityId = entityId;

			return this;
		}

		public Builder setEntityId(final Integer entityId) {
			this.entityId = (entityId == null ? null : entityId.toString());

			return this;
		}

		public Builder setUserId(final String userId) {
			this.userId = userId;

			return this;
		}

		public Builder setUserId(final Integer userId) {
			this.userId = (userId == null ? null : userId.toString());

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public ListRestorableEnrollmentsCommand build() {
			return new ListRestorableEnrollmentsCommand(this);
		}
	}
}