package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which lists sections that have been deleted and can be restored. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/ListRestorableSections">the BrainHoney DLAP API guide</a>} for
 * this command.
 */
public final class ListRestorableSectionsCommand implements Command {
	private final String courseId;
	private final String domainId;

	@SuppressWarnings("synthetic-access")
	private ListRestorableSectionsCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.courseId == null && builder.domainId == null)
			throw new IllegalArgumentException("Expected courseId or domainId to not be null.");
		else if(builder.courseId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.courseId))
			throw new IllegalArgumentException("Expected courseId to be valid.");
		else if(builder.domainId != null && !EntityIdAttributeValidator.getInstance().isValid(builder.domainId))
			throw new IllegalArgumentException("Expected domainId to be valid.");

		courseId = builder.courseId;
		domainId = builder.domainId;
	}

	public String getCourseId() {
		return courseId;
	}

	public String getDomainId() {
		return domainId;
	}

	/** A builder of immutable ListRestorableSectionsCommand instances. */
	public final static class Builder implements Command.Builder {
		private String courseId;
		private String domainId;

		public Builder() {
			super();
		}

		public Builder setCourseId(final String courseId) {
			this.courseId = courseId;

			return this;
		}

		public Builder setCourseId(final Integer courseId) {
			this.courseId = (courseId == null ? null : courseId.toString());

			return this;
		}

		public Builder setDomainId(final String domainId) {
			this.domainId = domainId;

			return this;
		}

		public Builder setDomainId(final Integer domainId) {
			this.domainId = (domainId == null ? null : domainId.toString());

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public ListRestorableSectionsCommand build() {
			return new ListRestorableSectionsCommand(this);
		}
	}
}