package com.rockymadden.jbrainhoney.dlap.command;

/**
 * A command which terminates the session state for an authenticated user. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/Logout">the BrainHoney DLAP API guide</a>}
 * for this command.
 */
public final class LogoutCommand implements Command, ObservableSessionCommand {
	private final SessionObserverManager sessionObserverManager;

	@SuppressWarnings("synthetic-access")
	private LogoutCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.sessionObserverManager == null)
			throw new IllegalArgumentException("Expected sessionObserverManager to not be null.");

		sessionObserverManager = builder.sessionObserverManager;
	}

	public SessionObserverManager getSessionObserverManager() {
		return sessionObserverManager;
	}

	@Override
	public LogoutCommand addObserver(final SessionObserver observer) {
		sessionObserverManager.addObserver(observer);

		return this;
	}

	@Override
	public LogoutCommand removeObserver(final SessionObserver observer) {
		sessionObserverManager.removeObserver(observer);

		return this;
	}

	/** A builder of immutable LogoutCommand instances. */
	public final static class Builder implements Command.Builder, ObservableSessionCommand.Builder {
		private final SessionObserverManager sessionObserverManager;

		public Builder() {
			super();

			this.sessionObserverManager = new SessionObserverManager();
		}

		@Override
		public Builder addObserver(final SessionObserver observer) {
			sessionObserverManager.addObserver(observer);

			return this;
		}

		@Override
		public Builder removeObserver(final SessionObserver observer) {
			sessionObserverManager.removeObserver(observer);

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public LogoutCommand build() {
			return new LogoutCommand(this);
		}
	}
}