package com.rockymadden.jbrainhoney.dlap.command;

import com.rockymadden.jbrainhoney.dlap.validate.EntityIdAttributeValidator;

/**
 * A command which updates the password of the specified user. See the
 * {@link <a href="http://gls.agilix.com/Docs/Command/UpdatePassword">the BrainHoney DLAP API guide</a>} for this
 * command.
 */
public final class UpdatePasswordCommand implements Command {
	private final String oldPassword;
	private final String password;
	private final String userId;

	@SuppressWarnings("synthetic-access")
	private UpdatePasswordCommand(final Builder builder) throws IllegalArgumentException {
		if(builder.password == null) throw new IllegalArgumentException("Expected password to not be null.");
		else if(builder.password.length() < 6)
			throw new IllegalArgumentException("Expected password to be at least 6 characters.");

		if(builder.userId == null) throw new IllegalArgumentException("Expected userId to not be null.");
		else if(!EntityIdAttributeValidator.getInstance().isValid(builder.userId))
			throw new IllegalArgumentException("Expected userId to be valid.");

		oldPassword = builder.oldPassword;
		password = builder.password;
		userId = builder.userId;
	}

	public String getOldPassword() {
		return oldPassword;
	}

	public String getPassword() {
		return password;
	}

	public String getUserId() {
		return userId;
	}

	/** A builder of immutable UpdatePasswordCommand instances. */
	public final static class Builder implements Command.Builder {
		private String oldPassword;
		private final String password;
		private final String userId;

		public Builder(final String userId, final String password) {
			super();

			this.userId = userId;
			this.password = password;
		}

		public Builder(final Integer userId, final String password) {
			super();

			this.userId = (userId == null ? null : userId.toString());
			this.password = password;
		}

		public Builder setOldPassword(final String oldPassword) {
			this.oldPassword = oldPassword;

			return this;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public UpdatePasswordCommand build() {
			return new UpdatePasswordCommand(this);
		}
	}
}