package com.rockymadden.jbrainhoney.dlap.element;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import com.rockymadden.jbrainhoney.dlap.enumeration.BitwiseValueEnumeration;

/** A utility class for bitwise attributes. */
public final class BitwiseUtility {
	private BitwiseUtility() {

	}

	public static <T extends BitwiseValueEnumeration> List<T> toEnumeration(final Long bitwise, final Set<T> bitwiseEnumerationSet)
		throws IllegalArgumentException {

		Long bw = bitwise;
		List<T> bitwiseEnumerations = new ArrayList<T>();
		List<Long> values = new ArrayList<Long>();
		Iterator<T> bitwiseEnumerationIterator = null;
		T bitwiseEnumeration = null;

		if(bitwise != null) {
			// Handles for both positive and negative.
			if(bw >= 0) {
				bitwiseEnumerationIterator = bitwiseEnumerationSet.iterator();

				while(bitwiseEnumerationIterator.hasNext()) {
					bitwiseEnumeration = bitwiseEnumerationIterator.next();

					if(bitwiseEnumeration.getValue() >= 0) values.add(bitwiseEnumeration.getValue());
				}

				Collections.sort(values, Collections.reverseOrder());

				for(Long value : values) {
					if(bw >= value) {
						bw -= value;

						bitwiseEnumerationIterator = bitwiseEnumerationSet.iterator();

						while(bitwiseEnumerationIterator.hasNext()) {
							bitwiseEnumeration = bitwiseEnumerationIterator.next();

							if((bitwiseEnumeration.getValue() > 0 && bitwiseEnumeration.getValue() == value)
								|| (bitwiseEnumeration.getValue() == 0 && bitwiseEnumeration.getValue() == value
								&& bitwiseEnumerations.size() == 0)) {

								bitwiseEnumerations.add(bitwiseEnumeration);
								break;
							}
						}
					}

					if(bw == 0 && bitwiseEnumerations.size() > 0) break;
				}
			} else {
				bitwiseEnumerationIterator = bitwiseEnumerationSet.iterator();

				while(bitwiseEnumerationIterator.hasNext()) {
					bitwiseEnumeration = bitwiseEnumerationIterator.next();

					if(bitwiseEnumeration.getValue() < 0) values.add(bitwiseEnumeration.getValue());
				}

				Collections.sort(values);

				for(Long value : values) {
					if(bw <= value) {
						bw -= value;

						bitwiseEnumerationIterator = bitwiseEnumerationSet.iterator();

						while(bitwiseEnumerationIterator.hasNext()) {
							bitwiseEnumeration = bitwiseEnumerationIterator.next();

							if(bitwiseEnumeration.getValue() == value) {
								bitwiseEnumerations.add(bitwiseEnumeration);
								break;
							}
						}
					}

					if(bw == 0) break;
				}
			}

			if(bw != 0) throw new IllegalArgumentException("Expected valid bitwise value.");
		}

		return Collections.synchronizedList(bitwiseEnumerations);
	}

	public static long toLong(final List<? extends BitwiseValueEnumeration> bitwiseEnumerations)
		throws IllegalArgumentException {

		long sum = 0l;
		boolean hasPositive = false;
		boolean hasNegative = false;

		for(BitwiseValueEnumeration enumeration : bitwiseEnumerations) {
			if(enumeration.getValue() > 0) hasPositive = true;
			else if(enumeration.getValue() < 0) hasNegative = true;

			if(hasPositive && hasNegative)
				throw new IllegalArgumentException("Expected positive or negative enumeration values, not both.");

			sum += enumeration.getValue();
		}

		return sum;
	}
}