package com.rockymadden.jbrainhoney.dlap.enumeration;

import java.util.EnumSet;
import org.joda.time.DateTime;
import org.joda.time.DateTimeZone;

/** Enumerates date boundaries. Start and end dates cannot be null, these are used in place of. */
public enum DateBoundary implements ValueEnumeration {
	MINIMUM(new DateTime(1754, 1, 1, 0, 0, 0, 0, DateTimeZone.UTC)), // 1754-01-01T00:00:00Z
	MAXIMUM(new DateTime(9999, 12, 31, 0, 0, 0, 0, DateTimeZone.UTC)); // 9999-12-31T00:00:00Z

	private final DateTime value;

	private DateBoundary(final DateTime value) {
		this.value = value;
	}

	@Override
	public DateTime getValue() {
		return value;
	}

	public static DateBoundary valueOfValue(final DateTime value) throws IllegalArgumentException {
		if(value == null) throw new IllegalArgumentException("Expected value to not be null.");

		DateBoundary enumeration = null;

		for(DateBoundary element : EnumSet.allOf(DateBoundary.class)) {
			if(element.getValue() != null && element.getValue().equals(value)) {
				enumeration = element;
				break;
			}
		}

		if(enumeration == null) throw new IllegalArgumentException("Expected value match.");

		return enumeration;
	}
}