package com.rockymadden.jbrainhoney.dlap.validate;

/** A validator class for a version attribute. */
public final class VersionAttributeValidator implements AttributeValidator<String> {
	private volatile static VersionAttributeValidator instance;

	private VersionAttributeValidator() {

	}

	public boolean isValid(final Integer version) {
		return isValid(version.toString());
	}

	@Override
	public boolean isValid(final String version) {
		if(version == null || version.length() == 0) return false;
		else if(!version.matches("\\d+") || Integer.parseInt(version) <= 0) return false;

		return true;
	}

	public static VersionAttributeValidator getInstance() {
		if(instance == null) synchronized(VersionAttributeValidator.class) {
			if(instance == null) instance = new VersionAttributeValidator();
		}

		return instance;
	}

	@Override
	public final java.lang.Object clone() throws CloneNotSupportedException {
		 throw new CloneNotSupportedException();
	}
}