package com.rockymadden.jbrainhoney.network;

/** An abstract implementation of an assignment based StringKeyValueParameter. */
public abstract class AssignmentStringKeyValueParameter implements StringKeyValueParameter {
	private static final long serialVersionUID = -740572946385222841L;
	protected final String key;
	protected final String value;

	protected AssignmentStringKeyValueParameter(final Builder builder) throws IllegalArgumentException {
		if(builder.key == null) throw new IllegalArgumentException("Expected key to not be null.");
		else if(builder.key.trim().length() == 0)
			throw new IllegalArgumentException("Expected key to have a length greater than 0.");

		key = unescape(builder.key);
		value = unescape(builder.value);
	}

	protected abstract String escape(final String escape);

	protected abstract String unescape(final String unescape);

	protected abstract String percentEncode(final String percentEncode);

	protected abstract String percentDecode(final String percentDecode);

	@Override
	public final String getKey() {
		return key;
	}

	@Override
	public final String getValue() {
		return value;
	}

	@Override
	public final boolean equals(final Object object) {
		if(object == this) return true;
		else if(!(object instanceof AssignmentStringKeyValueParameter)) return false;

		return toString().equals(((AssignmentStringKeyValueParameter)object).toString());
	}

	@Override
	public final int hashCode() {
		int hashCode = 17;
		hashCode = (31 * hashCode) + (toString() != null ? toString().hashCode() : 0);

		return hashCode;
	}

	@Override
	public final String toString() {
		return key + (value != null ? "=" + value : "");
	}

	@Override
	public final String toEscapedString() {
		return escape(key) + (value != null ? "=" + escape(value) : "");
	}

	@Override
	public final String toPercentEncodedString() {
		return percentEncode(key) + (value != null ? "=" + percentEncode(value) : "");
	}

	/** An abstract builder of immutable AssignmentStringKeyValueParameter instances. */
	public abstract static class Builder implements StringKeyValueParameter.Builder {
		protected final String key;
		protected final String value;

		protected Builder(final String key, final String value) {
			this.key = key;
			this.value = value;
		}

		protected Builder(final String key) {
			this.key = key;
			this.value = null;
		}

		@Override
		public abstract AssignmentStringKeyValueParameter build();
	}
}
