package com.rockymadden.jbrainhoney.network;

/** Defines the interface of a key/value pair based Parameter. */
public abstract interface KeyValueParameter<K extends Object, V extends Object> extends Parameter {
	public abstract K getKey();

	public abstract V getValue();

	/**
	 * @return The KeyValueParameter represented in a string format with, at minimum, delimiter/separator characters
	 * escaped via a backslash. For example, if parameters are delimited via the ampersand and pairs are separated via
	 * an equals sign: key=value&keyWith\=InIt&valueWith\&InIt
	 */
	public abstract String toEscapedString();

	/** @return The KeyValueParameter represented in a percent encoded string format.*/
	public abstract String toPercentEncodedString();

	/** Defines the interface of a KeyValueParameter builder. */
	public static interface Builder<K extends Object, V extends Object> extends Parameter.Builder {
		@Override
		public abstract KeyValueParameter<K, V> build();
	}
}
