package com.rockymadden.jbrainhoney.network.http.request;

import java.util.Arrays;

/** A byte array based implementation of a Body.*/
public final class ByteArrayBody implements Body {
	private static final long serialVersionUID = 46501294055631265L;
	private final byte[] value;
	private final String mimeType;

	@SuppressWarnings("synthetic-access")
	private ByteArrayBody(final Builder builder) throws IllegalArgumentException {
		if(builder.mimeType == null) throw new IllegalArgumentException("Expected mimeType to not be null.");
		else if(builder.mimeType.trim().length() == 0)
			throw new IllegalArgumentException("Expected mimeType to have a length greater than 0.");

		value = builder.value;
		mimeType = builder.mimeType;
	}

	@Override
	public final byte[] getValue() {
		return value;
	}

	@Override
	public final String getMimeType() {
		return mimeType;
	}

	@Override
	public final boolean equals(final Object object) {
		if(object == this) return true;
		else if(!(object instanceof ByteArrayBody)) return false;

		return toString().equals(((ByteArrayBody)object).toString());
	}

	@Override
	public final int hashCode() {
		int hashCode = 17;
		hashCode = (31 * hashCode) + (toString() != null ? toString().hashCode() : 0);

		return hashCode;
	}

	@Override
	public final String toString() {
		return ByteArrayBody.class.getSimpleName() + "(" + "mimeType=" + mimeType + (value != null ? ", value=" + Arrays.toString(value) : "") + ")";
	}

	/** A builder of immutable ByteArrayBody instances. */
	public static class Builder implements Body.Builder {
		private final byte[] value;
		private final String mimeType;

		public Builder(final byte[] value, final String mimeType) {
			this.value = value;
			this.mimeType = mimeType;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public ByteArrayBody build() {
			return new ByteArrayBody(this);
		}
	}
}