package com.rockymadden.jbrainhoney.network.http.request;

import com.rockymadden.jbrainhoney.network.http.HttpUri;

/** A post based implementation of a BodyEnclosingHttpRequest. */
public final class PostRequest implements BodyEnclosingHttpRequest {
	private static final long serialVersionUID = 37265023486029503L;
	private final Body body;
	private final HttpUri uri;

	@SuppressWarnings("synthetic-access")
	private PostRequest(final Builder builder) throws IllegalArgumentException {
		if(builder.uri == null) throw new IllegalArgumentException("Expected uri to not be null.");
		else if(builder.body == null) throw new IllegalArgumentException("Expected body to not be null.");

		body = builder.body;
		uri = builder.uri;
	}

	@Override
	public Body getBody() {
		return body;
	}

	@Override
	public HttpUri getUri() {
		return uri;
	}

	@Override
	public boolean equals(final Object object) {
		if(object == this) return true;
		else if(!(object instanceof PostRequest)) return false;

		return toString().equals(((PostRequest)object).toString());
	}

	@Override
	public int hashCode() {
		int hashCode = 17;
		hashCode = (31 * hashCode) + (toString() != null ? toString().hashCode() : 0);

		return hashCode;
	}

	@Override
	public String toString() {
		return PostRequest.class.getSimpleName() + "(" + (body != null ? "body=" + body.toString() + ", " : "") + "uri=" + uri.toString() + ")";
	}

	/** A builder of immutable PostRequest instances. */
	public final static class Builder implements HttpRequest.Builder {
		private final Body body;
		private final HttpUri uri;

		public Builder(final HttpUri uri, final Body body) {
			this.body = body;
			this.uri = uri;
		}

		@Override
		@SuppressWarnings("synthetic-access")
		public PostRequest build() {
			return new PostRequest(this);
		}
	}
}
